.. AAMUtils documentation master file, created by
   sphinx-quickstart on Mon Jul  8 17:27:13 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to AAMUtils’s documentation!
====================================

.. toctree::
   :maxdepth: 1

   doc/getting_started
   doc/reference
